from datetime import datetime
import importlib

from hdijupyterutils.constants import INSTANCE_ID
from hdijupyterutils.utils import get_instance_id


class Events(object):
    def __init__(self, handler):
        self.handler = handler

    @staticmethod
    def get_utc_date_time():
        return datetime.utcnow()

    def send_to_handler(self, kwargs_list):
        kwargs_list = [(INSTANCE_ID, get_instance_id())] + kwargs_list

        assert len(kwargs_list) <= 12

        self.handler.handle_event(kwargs_list)



from IPython.core.display import display, HTML
from IPython import get_ipython
import sys


class IpythonDisplay(object):
    def __init__(self):
        self._ipython_shell = get_ipython()

    def display(self, to_display):
        display(to_display)

    def html(self, to_display):
        self.display(HTML(to_display))

    def stderr_flush(self):
        sys.stderr.flush()

    def stdout_flush(self):
        sys.stdout.flush()

    def write(self, msg):
        sys.stdout.write(msg)
        self.stdout_flush()

    def writeln(self, msg):
        self.write("{}\n".format(msg))

    def send_error(self, error):
        sys.stderr.write("{}\n".format(error))
        self.stderr_flush()
